/*
 * Copyright (c) 2002-2005 Peter Bartoli <peter@bartoli.org>
             (c) 2005 Spiros Evangelatos <std00021@di.uoa.gr>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* dos/unix/mac text converter */

#include <stdio.h>
#include <errno.h>
#include <string.h>
#include <sys/param.h>

/* function prototypes */
char *basename (const char *);

int main (int argc, char **argv)
  {
  int buffer, buffer2;

  if (argc > 1)
    {
    fprintf (stderr, "%s takes only stdin and stdout\n", argv[0]);
    return (1);
    } /* if */

  if (strcmp (basename (argv[0]), "dos2unix") == 0)
    {
    while ((buffer = getchar ()) != EOF)
      if (buffer != '\r') putchar (buffer);
    return (0);
    } /* if: dos2unix */

  if (strcmp (basename (argv[0]), "dos2mac") == 0)
    {
    while ((buffer = getchar ()) != EOF)
      if (buffer != '\n') putchar (buffer);
    return (0);
    } /* if: dos2mac */

  if (strcmp (basename (argv[0]), "unix2dos") == 0)
    {
    while ((buffer = getchar ()) != EOF)
      {
      if (buffer == '\n') fprintf (stdout, "\r\n");
        else putchar (buffer);
      } /* while */
    return (0);
    } /* if: unix2dos */

  if (strcmp (basename (argv[0]), "unix2mac") == 0)
    {
    while ((buffer = getchar ()) != EOF)
      {
      if (buffer == '\n') putchar ('\r');
        else putchar (buffer);
      } /* while */
    return (0);
    } /* if: unix2mac */

  if (strcmp (basename (argv[0]), "mac2unix") == 0)
    {
    while ((buffer = getchar ()) != EOF)
      {
      if (buffer == '\r') putchar ('\n');
        else putchar (buffer);
      }
    return (0);
    } /* if: mac2unix */

  if (strcmp (basename (argv[0]), "mac2dos") == 0)
    {
    while ((buffer = getchar ()) != EOF)
      {
      if (buffer == '\r') fprintf (stdout, "\r\n");
        else putchar (buffer);
      }
    return (0);
    } /* if: mac2dos */

  if (strcmp (basename (argv[0]), "any2unix") == 0)
    {
    while ((buffer = getchar ()) != EOF)
      {
      if (buffer == '\r' || buffer == '\n')
        {
        putchar ('\n');
        buffer2 = getchar ();
        if ((buffer == buffer2) || (buffer2 != '\n' && buffer2 != '\r'))
          ungetc (buffer2, stdin);
        } /* if */
       else putchar (buffer);
      } /* while */
    return (0);
    } /* if: any2unix */

  /* won't get here unless installed improperly */
  fprintf (stderr, "error: dos/unix/mac conversion tool installed wonky\n");
  return (1);

  } /* main */

